
FRONTEND_DIR = 'frontend/dist'
FRONTEND_DIR_DEBUG = 'frontend'
FRONTEND_URL_PREFIX = 'frontend'
FRONTEND_APP_NAME = 'qtoggleserver'
FRONTEND_APP_DISPLAY_NAME = 'qToggleServer'
FRONTEND_APP_THEME_COLOR = '#62abea'
FRONTEND_APP_BACKGROUND_COLOR = '#444444'
FRONTEND_APP_DESCRIPTION = ''
